import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:minehunter/config/default_activity_settings.dart';

class ActivitySettings {
  final String level;
  final String size;

  ActivitySettings({
    required this.level,
    required this.size,
  });

  static String getLevelValueFromUnsafe(String level) {
    if (DefaultActivitySettings.allowedLevelValues.contains(level)) {
      return level;
    }

    return DefaultActivitySettings.defaultLevelValue;
  }

  static String getSizeValueFromUnsafe(String size) {
    if (DefaultActivitySettings.allowedSizeValues.contains(size)) {
      return size;
    }

    return DefaultActivitySettings.defaultSizeValue;
  }

  factory ActivitySettings.createDefault() {
    return ActivitySettings(
      level: DefaultActivitySettings.defaultLevelValue,
      size: DefaultActivitySettings.defaultSizeValue,
    );
  }

  void dump() {
    printlog('$ActivitySettings:');
    printlog('  ${DefaultActivitySettings.parameterCodeLevel}: $level');
    printlog('  ${DefaultActivitySettings.parameterCodeSize}: $size');
    printlog('');
  }

  @override
  String toString() {
    return '$ActivitySettings(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      DefaultActivitySettings.parameterCodeLevel: level,
      DefaultActivitySettings.parameterCodeSize: size,
    };
  }
}
